Index: /extensions/AMetaData/admin/amd_metadata.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata.tpl	(revision 10301)
+++ /extensions/AMetaData/admin/amd_metadata.tpl	(revision 10302)
@@ -1,5 +1,5 @@
-{known_script id="jquery.ui" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.core.packed.js"}
-{known_script id="jquery.ui.sortable" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.sortable.packed.js"}
-{known_script id="jquery.ui.dialog" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.dialog.packed.js"}
+{combine_script id="jquery.ui" path="themes/default/js/ui/minified/jquery.ui.core.min.js"}
+{combine_script id="jquery.ui.sortable" path="themes/default/js/ui/minified/jquery.ui.sortable.min.js"}
+{combine_script id="jquery.ui.dialog" src="themes/default/js/ui/minified/jquery.ui.dialog.min.js"}
 
 {$statTabsheet}
Index: /extensions/AMetaData/admin/amd_metadata_database.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_database.tpl	(revision 10301)
+++ /extensions/AMetaData/admin/amd_metadata_database.tpl	(revision 10302)
@@ -1,4 +1,4 @@
-{known_script id="jquery.ui" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.core.packed.js"}
-{known_script id="jquery.ui.dialog" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.dialog.packed.js"}
+{combine_script id="jquery.ui" path="themes/default/js/ui/minified/jquery.ui.core.min.js"}
+{combine_script id="jquery.ui.dialog" path="themes/default/js/ui/minified/jquery.ui.dialog.min.js"}
 
 {literal}
Index: /extensions/AMetaData/admin/amd_metadata_database_database.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_database_database.tpl	(revision 10301)
+++ /extensions/AMetaData/admin/amd_metadata_database_database.tpl	(revision 10302)
@@ -1,4 +1,4 @@
-{known_script id="jquery.ui" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.core.packed.js"}
-{known_script id="jquery.ui.dialog" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.dialog.packed.js"}
+{combine_script id="jquery.ui" path=$ROOT_URL|@cat:"themes/default/js/ui/minified/jquery.ui.core.min.js"}
+{combine_script id="jquery.ui.dialog" path=$ROOT_URL|@cat:"themes/default/js/ui/minified/jquery.ui.dialog.min.js"}
 
 {literal}
Index: /extensions/AMetaData/admin/amd_metadata_personnal.tpl
===================================================================
--- /extensions/AMetaData/admin/amd_metadata_personnal.tpl	(revision 10301)
+++ /extensions/AMetaData/admin/amd_metadata_personnal.tpl	(revision 10302)
@@ -1,8 +1,8 @@
-{known_script id="jquery.ui" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.core.packed.js"}
-{known_script id="jquery.ui.dialog" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.dialog.packed.js"}
-
-{known_script id="gpc.external.interface" src=$ROOT_URL|@cat:"plugins/GrumPluginClasses/js/external/interface/interface.js"}
-{known_script id="gpc.external.inestedsortable" src=$ROOT_URL|@cat:"plugins/GrumPluginClasses/js/external/inestedsortable.pack.js"}
-{known_script id="tagListSelector" src=$ROOT_URL|@cat:"plugins/AMetaData/js/tagListSelector.js"}
+{combine_script id="jquery.ui" path="themes/default/js/ui/minified/jquery.ui.core.min.js"}
+{combine_script id="jquery.ui.dialog" path="themes/default/js/ui/minified/jquery.ui.dialog.min.js"}
+
+{combine_script id="gpc.external.interface" path="plugins/GrumPluginClasses/js/external/interface/interface.js" require="jquery.ui"}
+{combine_script id="gpc.external.inestedsortable" path="plugins/GrumPluginClasses/js/external/inestedsortable.pack.js" require="gpc.external.interface"}
+{combine_script id="tagListSelector" path="plugins/AMetaData/js/tagListSelector.js" require="jquery"}
 
 
Index: /extensions/AMetaData/amd_version.inc.php
===================================================================
--- /extensions/AMetaData/amd_version.inc.php	(revision 10301)
+++ /extensions/AMetaData/amd_version.inc.php	(revision 10302)
@@ -17,6 +17,6 @@
   if (!defined('PHPWG_ROOT_PATH')) die('Hacking attempt!');
 
-  define('AMD_VERSION',  '0.5.9');
-  define('AMD_VERSION2', '00.05.09');
-  define('AMD_GPC_NEEDED', '3.3.2');
+  define('AMD_VERSION',  '0.6.0');
+  define('AMD_VERSION2', '00.06.00');
+  define('AMD_GPC_NEEDED', '3.5.0');
 ?>
Index: /extensions/AMetaData/main.inc.php
===================================================================
--- /extensions/AMetaData/main.inc.php	(revision 10301)
+++ /extensions/AMetaData/main.inc.php	(revision 10302)
@@ -2,5 +2,5 @@
 /*
 Plugin Name: Advanced MetaData
-Version: 0.5.9
+Version: 0.6.0
 Description: An advanced metadata manager
 Plugin URI: http://piwigo.org/ext/extension_view.php?eid=364
@@ -202,6 +202,6 @@
 |         |            |   . Array to strong conversion message on MagicTag "Author"
 |         |            |
-|         |            |
-|         |            |
+| 0.6.0   | 2011-04-11 | * mantis bug:2143
+|         |            |   . compatibility with piwigo 2.2
 |         |            |
 |         |            |
Index: /extensions/AMetaData/templates/amd_dialog_metadata_choose.tpl
===================================================================
--- /extensions/AMetaData/templates/amd_dialog_metadata_choose.tpl	(revision 10301)
+++ /extensions/AMetaData/templates/amd_dialog_metadata_choose.tpl	(revision 10302)
@@ -1,5 +1,5 @@
-{known_script id="jquery.ui" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.core.packed.js"}
-{known_script id="jquery.ui.dialog" src=$ROOT_URL|@cat:"themes/default/js/ui/packed/ui.dialog.packed.js"}
-{known_script id="tagListSelector" src=$ROOT_URL|@cat:"plugins/AMetaData/js/tagListSelector.js"}
+{combine_script id="jquery.ui" path="themes/default/js/ui/minified/jquery.ui.core.min.js"}
+{combine_script id="jquery.ui.dialog" path="themes/default/js/ui/minified/jquery.ui.dialog.min.js"}
+{combine_script id="tagListSelector" path="plugins/AMetaData/js/tagListSelector.js"}
 
 {literal}

Index: /extensions/AMetaData/maintain.inc.php
===================================================================
--- /extensions/AMetaData/maintain.inc.php	(revision 10301)
+++ /extensions/AMetaData/maintain.inc.php	(revision 10302)
@@ -38,6 +38,6 @@
 {
   @include_once(PHPWG_PLUGINS_PATH.'GrumPluginClasses/classes/CommonPlugin.class.inc.php');
-  // need GPC release greater or equal than 3.2.0
-  if(CommonPlugin::checkGPCRelease(3,2,0))
+  // need GPC release greater or equal than AMD_GPC_NEEDED
+  if(CommonPlugin::checkGPCRelease(AMD_GPC_NEEDED))
   {
     @include_once("amd_install.class.inc.php");